@@ -99,14 +99,14 @@ class Container(LyNode):
     
     @property
     def before(self):
-        if self.children():
+        if len(self):
             return self[0].before
         else:
             return 0
 
     @property
     def after(self):
-        if self.children():
+        if len(self):
             return self[-1].after
         else:
             return 0
@@ -761,7 +761,7 @@ class Duration(Leaf):
         self.factor = fractions.Fraction(factor)
 
     def ly(self, printer):
-        return ly.duration.duration(self.dur, self.dots, self.factor)
+        return ly.duration.tostring(self.dur, self.dots, self.factor)
 
 
 class Chord(Container):
